@@ -212,44 +212,3 @@ ggplot() +
   coord_equal() + 
   theme_bw()
 
-## -----------------------------------------------------------------------------
-flutd.tab <- matrix(c(13,2163,5,3349), nrow = 2, byrow = TRUE)
-rownames(flutd.tab) <- c("DF+", "DF-"); colnames(flutd.tab) <- c("FLUTD+", "FLUTD-")
-flutd.tab <- as.table(flutd.tab); flutd.tab
-
-## -----------------------------------------------------------------------------
-epi.2by2(dat = flutd.tab, method = "cross.sectional", conf.level = 0.95, 
-   units = 100, interpret = FALSE, outcome = "as.columns")
-
-## -----------------------------------------------------------------------------
-library(MASS)
-bwt <- birthwt; head(bwt)
-
-## -----------------------------------------------------------------------------
-low.tab <- table(bwt$smoke, bwt$low, dnn = c("Smoke", "Low BW")); low.tab
-
-## -----------------------------------------------------------------------------
-low.tab <- table(bwt$smoke, bwt$low, dnn = c("Smoke", "Low BW"))
-low.tab <- low.tab[2:1,2:1]; low.tab
-
-## -----------------------------------------------------------------------------
-bwt$low <- factor(bwt$low, levels = c(1,0))
-bwt$smoke <- factor(bwt$smoke, levels = c(1,0))
-bwt$race <- factor(bwt$race, levels = c(1,2,3))
-
-## -----------------------------------------------------------------------------
-low.tab <- table(bwt$smoke, bwt$low, dnn = c("Smoke", "Low BW")); low.tab
-
-## -----------------------------------------------------------------------------
-epi.2by2(dat = low.tab, method = "cohort.count", conf.level = 0.95, 
-   units = 100, interpret = FALSE, outcome = "as.columns")
-
-## -----------------------------------------------------------------------------
-low.stab <- table(bwt$smoke, bwt$low, bwt$race, dnn = c("Smoke", "Low BW", "Race"))
-low.stab
-
-## -----------------------------------------------------------------------------
-rval <- epi.2by2(dat = low.stab, method = "cohort.count", conf.level = 0.95, 
-   units = 100, interpret = FALSE, outcome = "as.columns")
-print(rval)
-
